@@ -1,10 +1,7 @@
 import pytest  # noqa
+from tippo import Any
 
-from basicco.dynamic_code import (
-    compile_and_eval,
-    generate_unique_filename,
-    make_function,
-)
+from basicco.dynamic_code import compile_and_eval, generate_unique_filename, make_function
 
 
 def test_generate_unique_filename():
@@ -14,7 +11,7 @@ def test_generate_unique_filename():
 
 
 def test_compile_and_eval():
-    globs = {}
+    globs = {}  # type: dict[str, Any]
     compile_and_eval("foo = 40", globs)
     compile_and_eval("bar = 2", globs)
     compile_and_eval("foobar = foo + bar", globs)
